import simpleParallax from 'simple-parallax-js';
import 'prismjs';
import LazyLoad from 'vanilla-lazyload';

if (window.NodeList && !NodeList.prototype.forEach) {
    NodeList.prototype.forEach = function(callback, thisArg) {
        thisArg = thisArg || window;
        for (var i = 0; i < this.length; i++) {
            callback.call(thisArg, this[i], i, this);
        }
    };
}

//Lazy Load Callback
const lazyLoadCallback = function(element) {

    let example = element.closest('.js-example'),
        options = {};

    if (example) {
        const exampleID = example.getAttribute('data-example-id');
        if (exampleID == 2) {
            options = {
                orientation: 'left'
            }
        } else if (exampleID == 3) {
            options = {
                scale: 1.5
            }
        } else if (exampleID == 4) {
            options = {
                scale: 1.8, 
                orientation: 'left', 
                overflow: true
            }
        } else if (exampleID == 5) {
            options = {
                scale: 1.4,
                delay: 2
            }
        }
    } else {
        options.scale = 1.2;
        if (element.classList.contains('up')) {
            options = {
                orientation: 'up'
            }
        } else if (element.classList.contains('down')) {
            options = {
                orientation: 'down'
            }
        } else if (element.classList.contains('right')) {
            options = {
                orientation: 'right'
            }
        } else if (element.classList.contains('left')) {
            options = {
                orientation: 'left'
            }
        }
    }
    new simpleParallax(element, options);

    if (element.closest('.diaporama__img')) {
        element.closest('.diaporama__img').classList.add('loaded');
    }
};

window.onload = function() {
    //Lazy Load options
    const myLazyLoadOptions = {
        threshold: 1000,
        callback_load: lazyLoadCallback
    };
    new LazyLoad(myLazyLoadOptions, {
        elements_selector: '.lazy'
    });
};

let lastPosition = -1,
    sectionName = '',
    lastSectionName = '',
    sections = document.querySelectorAll('.js-section');

//show the scroll up button
function sectionActive() {
    const viewportTop = window.pageYOffset;

    //is user hasn't scroll return
    if (viewportTop == lastPosition) {
        window.requestAnimationFrame(sectionActive);
        return;
    }

    //put active satte dynamically on section
    for (var i = 0; i < sections.length; i++) {
        let elementTopX = sections[i].offsetTop,
            elementBottomX = elementTopX + sections[i].offsetHeight,
            viewportBottom = viewportTop + document.documentElement.clientHeight;

        if (elementBottomX > viewportTop && elementTopX < viewportBottom) {
            var itemsNav = document.querySelectorAll('.js-nav li');
            itemsNav.forEach(function(itemNav) {
                itemNav.classList.remove('active');
            });

            let sectionId = sections[i].getAttribute('data-section-id') * 1;

            document.querySelector('.js-nav li[data-section-id="' + sectionId + '"').classList.add('active');

            sectionName = sections[i].getAttribute('data-section-name');

            if (sectionName != lastSectionName) {
                if (typeof gtag != 'undefined') {
                    gtag('config', 'UA-93163144-2', {
                        page_title: sectionName,
                        page_path: '/' + sectionName.toLowerCase()
                    });
                }
            }

            break;
        }
    }

    //display the nav
    const mainSection = document.getElementById('installation'),
        mainSectionOffsetTop = mainSection.offsetTop;

    if (viewportTop > mainSectionOffsetTop) {
        document.querySelector('.js-nav').classList.add('active');
        document.querySelector('.js-share').classList.add('active');
    } else {
        document.querySelector('.js-nav').classList.remove('active');
        document.querySelector('.js-share').classList.remove('active');
    }

    //cache the last position
    lastPosition = viewportTop;
    lastSectionName = sectionName;

    window.requestAnimationFrame(sectionActive);
}

if (sections) {
    sectionActive();
}

//init Smooth Scroll
var SmoothScroll = require('smooth-scroll/dist/smooth-scroll.js');
new SmoothScroll('a[href*="#"]');

//social share
let socialShares = document.querySelectorAll('.share__link');
if (socialShares) {
    socialShares.forEach(function(socialShare) {
        socialShare.addEventListener('click', function(e) {
            let socialName = this.getAttribute('data-sharer');
            if (typeof gtag != 'undefined') {
                gtag('event', 'click', {
                    'event_category': 'social_share',
                    'event_label': socialName
                });
            }
        });
    })
}

setTimeout(() => {
    document.querySelector('.modal').classList.add('active');
    if (typeof gtag != 'undefined') {
        gtag('event', 'display', {
            'event_category': 'modal',
            'event_label': 'modal'
        });
    }
    document.addEventListener('click', function(e) {
        e.preventDefault();
        let target = e.target;
        if (!target.closest('.modal__container')) {
            document.querySelector('.modal').classList.remove('active');
        }
    })
    document.querySelector('.modal__close').addEventListener('click', function(e) {
        e.preventDefault();
        document.querySelector('.modal').classList.remove('active');
    })
}, 30000);